@@ -13,6 +13,10 @@ def download_file_from_google_drive(destination):
     def save_response_content(response, destination):
         CHUNK_SIZE = 32768
 
+        dirname = os.path.dirname(destination)
+        if not os.path.exists(dirname):
+            os.makedirs(dirname)
+
         with open(destination, "wb+") as f:
             for chunk in response.iter_content(CHUNK_SIZE):
                 if chunk: # filter out keep-alive new chunks
